@@ -100,10 +100,6 @@ BASE_PATTERN = FoolfuukaExtractor.update({
         "root": "https://thebarchive.com",
         "pattern": r"thebarchive\.com",
     },
-    "wakarimasen": {
-        "root": "https://archive.wakarimasen.moe",
-        "pattern": r"archive\.wakarimasen\.moe",
-    },
 })
 
 
@@ -149,9 +145,6 @@ class FoolfuukaThreadExtractor(FoolfuukaExtractor):
         ("https://thebarchive.com/b/thread/739772332/", {
             "url": "e8b18001307d130d67db31740ce57c8561b5d80c",
         }),
-        ("https://archive.wakarimasen.moe/a/thread/223157648/", {
-            "url": "fef0758d2eb81b1ba783051fd5ec491d70107a78",
-        }),
     )
 
     def __init__(self, match):
@@ -190,7 +183,6 @@ class FoolfuukaBoardExtractor(FoolfuukaExtractor):
         ("https://archive.nyafuu.org/c/"),
         ("https://rbt.asia/g/"),
         ("https://thebarchive.com/b/"),
-        ("https://archive.wakarimasen.moe/a/"),
     )
 
     def __init__(self, match):
@@ -234,7 +226,6 @@ class FoolfuukaSearchExtractor(FoolfuukaExtractor):
         ("https://archive.nyafuu.org/_/search/text/test/"),
         ("https://rbt.asia/_/search/text/test/"),
         ("https://thebarchive.com/_/search/text/test/"),
-        ("https://archive.wakarimasen.moe/a/search/text/test/"),
     )
 
     def __init__(self, match):
@@ -300,7 +291,6 @@ class FoolfuukaGalleryExtractor(FoolfuukaExtractor):
         ("https://archive.nyafuu.org/c/gallery/7"),
         ("https://rbt.asia/g/gallery/8"),
         ("https://thebarchive.com/b/gallery/9"),
-        ("https://archive.wakarimasen.moe/a/gallery/10"),
     )
 
     def __init__(self, match):
